@@ -3,10 +3,12 @@ import logging
 from datetime import datetime
 from pathlib import Path
 from sys import exit, stderr, stdout
+from typing import Callable
 
 import click
 from pydantic import ValidationError
 
+from ._click_opt_groups import GroupCmd, GroupOpt
 from ._logging_utils import TermEscapeCodeFormatter, duqlog_screen
 from .config import cfg
 from .operations import op_queue, op_queue_context
@@ -24,7 +26,9 @@ def config_option(f):
     return click.option('-c',
                         '--config',
                         default='duqtools.yaml',
-                        help='Path to config.')(f)
+                        help='Path to config.',
+                        cls=GroupOpt,
+                        group='Common options')(f)
 
 
 def quiet_option(f):
@@ -33,57 +37,106 @@ def quiet_option(f):
                         is_flag=True,
                         default=False,
                         help='Don\'t output anything to the screen'
-                        ' (except mandatory prompts).')(f)
+                        ' (except mandatory prompts).',
+                        cls=GroupOpt,
+                        group='Common options')(f)
 
 
 def debug_option(f):
+    """Must be added together with `logfile_option`."""
     return click.option('--debug',
                         is_flag=True,
-                        help='Enable debug print statements.')(f)
+                        help='Enable debug print statements.',
+                        cls=GroupOpt,
+                        group='Common options')(f)
 
 
 def dry_run_option(f):
     return click.option('--dry-run',
                         is_flag=True,
-                        help='Execute without any side-effects.')(f)
+                        help='Execute without any side-effects.',
+                        cls=GroupOpt,
+                        group='Common options')(f)
 
 
 def yes_option(f):
     return click.option('--yes',
                         is_flag=True,
-                        help='Answer yes to questions automatically.')(f)
+                        help='Answer yes to questions automatically.',
+                        cls=GroupOpt,
+                        group='Common options')(f)
 
 
 def logfile_option(f):
+    """Must be added together with `debug_option`."""
     return click.option('--logfile',
                         '-l',
                         is_flag=False,
                         default='duqtools.log',
                         help='where to send the logfile,'
                         ' the special values stderr/stdout'
-                        ' will send it there respectively.')(f)
+                        ' will send it there respectively.',
+                        cls=GroupOpt,
+                        group='Common options')(f)
 
 
-def parse_common_options(func):
-    """With this function it becomes possible to parse the options in user
-    defined order."""
+all_options = (logfile_option, debug_option, config_option, quiet_option,
+               dry_run_option, yes_option)
 
-    def parse_options(ctx, *, logfile, debug, quiet, dry_run, config, yes,
-                      **kwargs):
-        # Config option
-        if ctx.command.name != 'init':
-            try:
-                cfg.parse_file(config)
-            except ValidationError as e:
-                exit(e)
 
-        # Debug option
-        if debug:
-            level = logging.DEBUG
-        else:
-            level = logging.INFO
+def handles_option(f):
+    return click.option('-h',
+                        '--handle',
+                        'handles',
+                        type=str,
+                        help='IMAS data handles.',
+                        multiple=True)(f)
+
+
+def variables_option(f):
+    return click.option('-v',
+                        '--variable',
+                        'var_names',
+                        type=str,
+                        help='Name of the variables.',
+                        multiple=True)(f)
+
+
+def datafile_option(f):
+    return click.option('-i',
+                        '--input',
+                        'input_files',
+                        type=str,
+                        help='Input file, i.e. `data.csv` or `runs.yaml`',
+                        multiple=True)(f)
+
+
+class OptionParser:
+
+    def wrap(self, func: Callable):
+        """With this wrapper it becomes possible to parse common options in
+        user defined order."""
+
+        def callback(**kwargs):
+            for parse in (
+                    self.parse_config,
+                    self.parse_logfile,
+                    self.parse_yes,
+                    self.parse_dry_run,
+                    self.parse_quiet,
+            ):
+                try:
+                    parse(**kwargs)
+                except TypeError:
+                    # Skip when option has not been set
+                    pass
+            func(**kwargs)
+
+        return callback
+
+    def parse_logfile(self, *, logfile, debug, **kwargs):
+        level = logging.DEBUG if debug else logging.INFO
 
-        # Logfile option
         streams = {'stdout': stdout, 'stderr': stderr}
         logging.getLogger().handlers = []
 
@@ -105,40 +158,43 @@ def parse_common_options(func):
         logger.info('------------------------------------------------')
         logger.info('')
 
-        # Yes option
-        op_queue.yes = yes
-
-        # Dry run option
-        op_queue.dry_run = dry_run
-
-        # Quiet option
+    def parse_quiet(self, *, quiet, **kwargs):
         if quiet:
             duqlog_screen.handlers = []  # remove output methods
             cfg.quiet = True
 
-    def callback(ctx, **kwargs):
-        parse_options(ctx, **kwargs)
-        func(**kwargs)
+    def parse_dry_run(self, *, dry_run, **kwargs):
+        op_queue.dry_run = dry_run
 
-    return callback
+    def parse_config(self, *, config, **kwargs):
+        try:
+            cfg.parse_file(config)
+        except ValidationError as e:
+            exit(e)
+
+    def parse_yes(self, *, yes, **kwargs):
+        op_queue.yes = yes
 
 
-def common_options(func):
+def common_options(*options):
     """common_options.
 
     IMPORTANT: This must be the last click option specified before
     the execution of the actual function, otherwise options will be
     missing
     """
-    wrapper = click.pass_context(parse_common_options(func))
 
-    for option in (logfile_option, debug_option, config_option, quiet_option,
-                   dry_run_option, yes_option):
-        wrapper = option(wrapper)
+    def decorator(func):
+        wrapper = OptionParser().wrap(func)
 
-    functools.update_wrapper(wrapper, func)
+        for option in options:
+            wrapper = option(wrapper)
 
-    return wrapper
+        functools.update_wrapper(wrapper, func)
+
+        return wrapper
+
+    return decorator
 
 
 def cli_entry():
@@ -156,9 +212,15 @@ def cli(**kwargs):
     pass
 
 
-@cli.command('init')
+@cli.command('init', cls=GroupCmd)
+@click.option('-o',
+              '--out',
+              'out_file',
+              help='Path to write config to (default=duqtools.yaml).',
+              default='duqtools.yaml')
 @click.option('--force', is_flag=True, help='Overwrite existing config.')
-@common_options
+@common_options(logfile_option, debug_option, quiet_option, dry_run_option,
+                yes_option)
 def cli_init(**kwargs):
     """Create a default config file."""
     from .init import init
@@ -169,11 +231,11 @@ def cli_init(**kwargs):
             exit(e)
 
 
-@cli.command('create')
+@cli.command('create', cls=GroupCmd)
 @click.option('--force',
               is_flag=True,
               help='Overwrite existing run directories and IDS data.')
-@common_options
+@common_options(*all_options)
 def cli_create(**kwargs):
     """Create the UQ run files."""
     from .create import create
@@ -181,22 +243,23 @@ def cli_create(**kwargs):
         create(**kwargs)
 
 
-@cli.command('recreate')
-@click.argument('runs', nargs=-1)
-@common_options
+@cli.command('recreate', cls=GroupCmd)
+@click.argument('runs', type=Path, nargs=-1)
+@common_options(*all_options)
 def cli_recreate(**kwargs):
     """Read `runs.yaml` and re-create the given runs.
 
-    Example:
     \b
-    - duqtools recreate run_0003 run_0004 --force
+    Example:
+
+    - `duqtools recreate run_0003 run_0004 --force`
     """
     from .create import recreate
     with op_queue_context():
         recreate(**kwargs)
 
 
-@cli.command('submit')
+@cli.command('submit', cls=GroupCmd)
 @click.option('--force',
               is_flag=True,
               help='Re-submit running or completed jobs.')
@@ -215,7 +278,7 @@ def cli_recreate(**kwargs):
               default=tuple(),
               type=Path,
               help='Case to re-submit, can be specified multiple times')
-@common_options
+@common_options(*all_options)
 def cli_submit(**kwargs):
     """Submit the UQ runs.
 
@@ -231,10 +294,10 @@ def cli_submit(**kwargs):
         submit(**kwargs)
 
 
-@cli.command('status')
+@cli.command('status', cls=GroupCmd)
 @click.option('--detailed', is_flag=True, help='Detailed info on progress')
 @click.option('--progress', is_flag=True, help='Fancy progress bar')
-@common_options
+@common_options(*all_options)
 def cli_status(**kwargs):
     """Print the status of the UQ runs."""
     from .status import status
@@ -242,42 +305,8 @@ def cli_status(**kwargs):
 
 
 @cli.command('plot')
-@click.option('-x',
-              'grid_var',
-              default='rho_tor_norm',
-              type=str,
-              help='Name of the x (grid) variable')
-@click.option('-y',
-              'data_vars',
-              type=str,
-              help='Name of the y (data) variable(s)',
-              multiple=True)
-@click.option('-t',
-              'time_var',
-              type=str,
-              help='Name of the time variable',
-              default='time')
-@click.option('-m',
-              '--imas',
-              'imas_paths',
-              type=str,
-              help='IMAS path formatted as <user>/<db>/<shot>/<number>.',
-              multiple=True)
-@click.option('-u', '--user', 'user', type=str, help='IMAS user.')
-@click.option('-d', '--db', 'db', type=str, help='IMAS database.')
-@click.option('-s', '--shot', 'shot', type=int, help='IMAS shot.')
-@click.option('-r',
-              '--runs',
-              'runs',
-              type=int,
-              multiple=True,
-              help='IMAS run (multiple runs can be specified)')
-@click.option('-i',
-              '--input',
-              'input_files',
-              type=str,
-              help='Input file, i.e. `data.csv` or `runs.yaml`',
-              multiple=True)
+@handles_option
+@variables_option
 @click.option('-o',
               '--format',
               'extensions',
@@ -285,27 +314,33 @@ def cli_status(**kwargs):
               help='Output format (json, html, png, svg, pdf), default: html.',
               default=('html', ),
               multiple=True)
+@click.option('-e',
+              '--errorbars',
+              is_flag=True,
+              help='Plot the errorbars (if present)')
+@datafile_option
 def cli_plot(**kwargs):
     """Plot some IDS data.
 
     \b
     Examples:
-    - duqtools plot -x rho_tor_norm -y t_i_ave -y zeff -i data.csv
-    - duqtools plot -y t_i_ave -y zeff -m jet/91234/5
-    - duqtools plot -y zeff -u user -d jet -s 91234 -r 5 -r 6 -r 7
-    - duqtools plot -y zeff -m user/91234/5 -i data.csv
-    - duqtools plot -y zeff -m user/91234/5 -o json
+
+    - `duqtools plot -v t_i_ave -v zeff -i data.csv`
+    - `duqtools plot -v t_i_ave -v zeff -h user/jet/91234/5`
+    - `duqtools plot -v zeff -h db/91234/5 -h db/91234/6 -h db/91234/7`
+    - `duqtools plot -v zeff -h db/91234/5 -i data.csv`
+    - `duqtools plot -v zeff -h db/91234/5 -o json`
     """
     from .plot import plot
     plot(**kwargs)
 
 
-@cli.command('clean')
+@cli.command('clean', cls=GroupCmd)
 @click.option('--out', is_flag=True, help='Remove output data.')
 @click.option('--force',
               is_flag=True,
               help='Overwrite backup file if necessary.')
-@common_options
+@common_options(*all_options)
 def cli_clean(**kwargs):
     """Delete generated IDS data and the run dir."""
     from .cleanup import cleanup
@@ -313,9 +348,9 @@ def cli_clean(**kwargs):
         cleanup(**kwargs)
 
 
-@cli.command('go')
+@cli.command('go', cls=GroupCmd)
 @click.option('--force', is_flag=True, help='Overwrite files when necessary.')
-@common_options
+@common_options(*all_options)
 def cli_go(**kwargs):
     """Run create, submit, status, dash in succession.
 
@@ -349,18 +384,63 @@ def cli_yolo(ctx, **kwargs):
     ctx.invoke(cli_go, force=True, quiet=True, yes=True)
 
 
-@cli.command('dash')
-@common_options
+@cli.command('dash', cls=GroupCmd)
+@common_options(*all_options)
 def cli_dash(**kwargs):
     """Open dashboard for evaluating IDS data."""
     from .dash import dash
     dash(**kwargs)
 
 
-@cli.command('merge')
-@common_options
+@cli.command('merge', cls=GroupCmd)
+@handles_option
+@variables_option
+@click.option('-t',
+              '--template',
+              required=True,
+              type=str,
+              help='IMAS location to use as the template for the target')
+@click.option('-o',
+              '--out',
+              'target',
+              required=True,
+              type=str,
+              help='IMAS location to store the result in')
+@click.option('--all',
+              'merge_all',
+              is_flag=True,
+              help='Try to merge all known variables.')
+@datafile_option
+@click.option('--force',
+              is_flag=True,
+              help='Overwrite existing output dataset.')
+@common_options(*all_options)
 def cli_merge(**kwargs):
-    """Merge data sets with error propagation."""
+    """Merge data sets with error propagation.
+
+    Example Merging two IDSes. Run number `8000` is the template.
+    Only The `t_e` variable is merged.
+
+    The resulting IDS is saved to your own test database with
+    shot number `36982` and run number `9999`.
+
+    Example:
+
+    \b
+    ```
+    duqtools merge \\
+        -t g2jcitri/aug/36982/8000 \\
+        -o test/36982/9999 \\
+        -h g2jcitri/aug/36982/8001 \\
+        -h g2jcitri/aug/36982/8000 \\
+        -v t_e
+    ```
+    \f
+    Note:
+
+    The `-t`, `-o` and `-h` options expect an IMAS path formatted as
+    `user/db/shot/number` or `db/shot/number`.
+    """
     from .merge import merge
     with op_queue_context():
         merge(**kwargs)
