@@ -3,9 +3,10 @@ import logging
 from ._handle import ImasHandle
 from ._imas import imas_mocked
 from ._mapping import IDSMapping
-from ._merge import merge_data, queue_merge_data
-from ._rebase import (rebase_on_grid, rebase_on_time, standardize_datasets,
-                      standardize_grid, standardize_time)
+from ._merge import merge_data
+from ._rebase import (rebase_all_coords, rebase_on_grid, rebase_on_time,
+                      squash_placeholders, standardize_grid,
+                      standardize_grid_and_time, standardize_time)
 
 logger = logging.getLogger(__name__)
 
@@ -15,9 +16,10 @@ __all__ = [
     'merge_data',
     'rebase_on_grid',
     'rebase_on_time',
-    'standardize_datasets',
+    'rebase_all_coords',
+    'standardize_grid_and_time',
     'standardize_grid',
     'standardize_time',
+    'squash_placeholders',
     'imas_mocked',
-    'queue_merge_data',
 ]
