@@ -12,14 +12,17 @@ from ..schema import IDSVariableModel, ImasBaseModel
 from ._copy import copy_ids_entry
 from ._imas import imas, imasdef
 from ._mapping import IDSMapping
+from ._rebase import squash_placeholders
 
 if TYPE_CHECKING:
     import xarray as xr
 
 logger = logging.getLogger(__name__)
 
-PATH_TEMPLATE = ('/afs/eufus.eu/user/g/{user}/public/imasdb/{db}'
-                 '/3/0/ids_{shot}{run:04d}{suffix}')
+PATH_TEMPLATE = str(Path.home().parent.joinpath('{user}', 'public', 'imasdb',
+                                                '{db}', '3', '0',
+                                                'ids_{shot}{run:04d}{suffix}'))
+
 SUFFIXES = (
     '.datafile',
     '.characteristics',
@@ -46,6 +49,9 @@ def _patch_str_repr(obj: object):
 
 class ImasHandle(ImasBaseModel):
 
+    def __str__(self):
+        return f'{self.user}/{self.db}/{self.shot}/{self.run}'
+
     @classmethod
     def from_string(cls, string: str) -> ImasHandle:
         """Return location from formatted string.
@@ -115,10 +121,6 @@ class ImasHandle(ImasBaseModel):
             raise OSError(f'Failed to copy {self}') from err
 
     @add_to_op_queue('Removing ids', '{self}')
-    def queue_delete(self):
-        """Queued version of `ImasHandle.delete()`."""
-        return self.delete()
-
     def delete(self):
         """Remove data from entry."""
         # ERASE_PULSE operation is yet supported by IMAS as of June 2022
@@ -171,6 +173,7 @@ class ImasHandle(ImasBaseModel):
     def get_variables(
         self,
         variables: Sequence[Union[str, IDSVariableModel]],
+        squash: bool = True,
         **kwargs,
     ) -> xr.Dataset:
         """Get variables from data set.
@@ -182,6 +185,8 @@ class ImasHandle(ImasBaseModel):
         ----------
         variables : Sequence[Union[str, IDSVariableModel]]
             Variable names of the data to load.
+        squash : bool
+            Squash placeholder variables
 
         Returns
         -------
@@ -209,6 +214,9 @@ class ImasHandle(ImasBaseModel):
 
         ds = data_map.to_xarray(variables=var_models, **kwargs)
 
+        if squash:
+            ds = squash_placeholders(ds)
+
         return ds
 
     def entry(self, backend=imasdef.MDSPLUS_BACKEND):
