@@ -1,13 +1,11 @@
 """This module contains tools for interfacing with jetto runs."""
 
-from ._copy import copy_files
+from ._jettovar_to_json import jettovar_to_json
 from ._llcmd import write_batchfile
-from ._settings_manager import JettoSettingsManager
 from ._system import JettoSystem
 
 __all__ = [
+    'jettovar_to_json',
     'write_batchfile',
-    'JettoSettingsManager',
-    'copy_files',
     'JettoSystem',
 ]
