@@ -1,10 +1,13 @@
 from __future__ import annotations
 
+import sys
+
 from pydantic import Field
-from typing_extensions import Literal
 
 from ._basemodel import BaseModel
 
+from typing import Literal
+
 
 class LHSSampler(BaseModel):
     """Select the Latin Hypercube sampler by specifying
